const {
  User,
  Email,
  services,
  Fragment,
} = require('pubsweet-component-helper-service')
const { getEmailCopy } = require('./emailCopy')

module.exports = {
  async sendNotifications({
    baseUrl,
    collection,
    User: UserModel,
    Fragment: FragmentModel,
  }) {
    const fragment = await FragmentModel.find(collection.fragments[0])
    const fragmentHelper = new Fragment({ fragment })
    const parsedFragment = await fragmentHelper.getFragmentData({
      handlingEditor: collection.handlingEditor,
    })
    const { submittingAuthor } = await fragmentHelper.getAuthorData({
      UserModel,
    })

    const titleText = `the manuscript titled "${parsedFragment.title}" by ${
      submittingAuthor.firstName
    } ${submittingAuthor.lastName}`

    const userHelper = new User({ UserModel })

    const email = new Email({
      type: 'user',
      content: {
        subject: `${collection.customId}: Manuscript Passed Technical Checks`,
        signatureName: 'EQS Team',
        ctaLink: services.createUrl(
          baseUrl,
          `/projects/${collection.id}/versions/${fragment.id}/details`,
        ),
        ctaText: 'MANUSCRIPT DETAILS',
        unsubscribeLink: baseUrl,
      },
    })

    const editors = (await userHelper.getEditorsInChief()).map(eic => ({
      ...eic,
      ...getEmailCopy({
        emailType: 'eqs-manuscript-accepted',
        titleText,
      }),
    }))

    editors.forEach(eic => {
      email.toUser = {
        email: eic.email,
        name: `${eic.firstName} ${eic.lastName}`,
      }
      const { html, text } = email.getBody({
        body: { paragraph: eic.paragraph, hasLink: eic.hasLink },
      })
      email.sendEmail({ html, text })
    })
  },
}
