import React from 'react'
import { compose } from 'recompose'
import { connect } from 'react-redux'
import { reduxForm } from 'redux-form'
import styled from 'styled-components'
import { required } from 'xpub-validators'
import { selectCurrentUser } from 'xpub-selectors'
import { Button, th, TextField, ValidatedField } from '@pubsweet/ui'
import {
  onSubmitChangePassword as onSubmit,
  changePasswordValidator,
} from '../utils'

import { Row, RowItem, Label, Title, Err } from '../UIComponents/FormItems'

const PasswordField = input => <TextField {...input} type="password" />

const ChangePassword = ({ history, handleSubmit, error }) => (
  <Root>
    <Form onSubmit={handleSubmit}>
      <Row>
        <RowItem vertical>
          <Title>Change Password</Title>
        </RowItem>
      </Row>
      <Row>
        <RowItem vertical>
          <Label>Current Password *</Label>
          <ValidatedField
            component={PasswordField}
            name="password"
            validate={[required]}
          />
        </RowItem>
      </Row>
      <Row>
        <RowItem vertical>
          <Label>New Password *</Label>
          <ValidatedField
            component={PasswordField}
            name="newPassword"
            validate={[required]}
          />
        </RowItem>
      </Row>
      <Row>
        <RowItem vertical>
          <Label>Re-type password *</Label>
          <ValidatedField
            component={PasswordField}
            name="confirmNewPassword"
            validate={[required]}
          />
        </RowItem>
      </Row>
      {error && (
        <Row>
          <RowItem>
            <Err>{error}</Err>
          </RowItem>
        </Row>
      )}
      <Row />
      <Row>
        <Button onClick={history.goBack}>Cancel</Button>
        <Button primary type="submit">
          Update
        </Button>
      </Row>
    </Form>
  </Root>
)

export default compose(
  connect(state => ({
    user: selectCurrentUser(state),
  })),
  reduxForm({
    form: 'changePassword',
    onSubmit,
    validate: changePasswordValidator,
  }),
)(ChangePassword)

// #region styles
const Root = styled.div`
  display: flex;
  flex-direction: column;
  max-width: 30em;
  margin: 0 auto;
`
const Form = styled.form`
  background-color: ${th('colorBackground')};
  padding: ${th('gridUnit')};
  border: ${th('borderDefault')};
`

// #endregion
